"""
examples.finalizers
~~~~~~~~~~~~~~~~~~~

Success and Failure finalizers.
"""

import time

from yaspin import yaspin


def default_finalizers():
    with yaspin(text="Downloading...") as sp:
        time.sleep(2)
        sp.ok()

    with yaspin(text="Downloading...") as sp:
        time.sleep(2)
        sp.fail()


def custom_finalizers():
    with yaspin(text="Processing...") as sp:
        time.sleep(2)
        # Make finalizer green
        sp.green.ok("✔")

    with yaspin(text="Processing...") as sp:
        time.sleep(2)
        # Make finalizer red
        sp.red.fail("✘")


def main():
    default_finalizers()
    custom_finalizers()


if __name__ == "__main__":
    main()



"""
tests.test_properties
~~~~~~~~~~~~~~~~~~~~~

Test getters and setters.
"""

import pytest

from yaspin import Spinner, yaspin
from yaspin.base_spinner import default_spinner
from yaspin.helpers import to_unicode


#
# Yaspin.spinner
#
def test_spinner_getter(frames, interval):
    sp = yaspin()
    assert sp.spinner == default_spinner

    new_spinner = Spinner(frames, interval)
    sp.spinner = new_spinner
    assert sp.spinner == sp._set_spinner(new_spinner)


def test_spinner_setter(frames, interval):
    sp = yaspin()
    assert sp._spinner == default_spinner
    assert isinstance(sp._frames, str)
    assert sp._interval == sp._spinner.interval * 0.001
    assert isinstance(repr(sp), str)

    new_spinner = Spinner(frames, interval)
    sp.spinner = new_spinner
    assert sp._spinner == sp._set_spinner(new_spinner)

    assert not isinstance(sp._frames, bytes)

    if isinstance(sp._frames, (list, tuple)):
        assert isinstance(sp._frames[0], str)

    assert sp._interval == sp._spinner.interval * 0.001
    assert isinstance(repr(sp), str)


#
# Yaspin.text
#
def test_text_getter(text):
    sp = yaspin(text=text)
    assert sp.text == to_unicode(text)


def test_text_setter(text):
    sp = yaspin()
    sp.text = text
    assert isinstance(sp._text, str)
    assert sp._text == to_unicode(text)


#
# Yaspin.side
#
def test_side_getter(side):
    sp = yaspin(side=side)
    assert sp.side == side


@pytest.mark.parametrize(
    "side, expected",
    [("left", "left"), ("right", "right"), ("center", ValueError())],
)
def test_side_setter(side, expected):
    sp = yaspin()
    assert sp._side == "left"

    if isinstance(expected, Exception):
        with pytest.raises(type(expected)):
            sp.side = side
    else:
        sp.side = side
        assert sp._side == expected


#
# Yaspin.reversal
#
def test_reversal_getter(reversal):
    sp = yaspin(reversal=reversal)
    assert sp.reversal == reversal


def test_reversal_setter(reversal):
    sp = yaspin()
    sp.reversal = reversal
    assert isinstance(sp._frames, str)
    assert sp._reversal == reversal


#
# Yaspin.color
#
def test_color_getter(supported_colors):
    color = supported_colors
    sp = yaspin(color=color)
    assert sp.color == color


def test_color_setter(color_test_cases):
    color, expected = color_test_cases
    sp = yaspin()

    if isinstance(expected, Exception):
        with pytest.raises(type(expected)):
            sp.color = color
    else:
        sp.color = color
        assert sp._color == expected


#
# Yaspin.on_color
#
def test_on_color_getter(supported_highlights):
    on_color = supported_highlights
    sp = yaspin(on_color=on_color)
    assert sp.on_color == on_color


def test_on_color_setter(on_color_test_cases):
    on_color, expected = on_color_test_cases
    sp = yaspin()

    if isinstance(expected, Exception):
        with pytest.raises(type(expected)):
            sp.on_color = on_color
    else:
        sp.on_color = on_color
        assert sp._on_color == expected


#
# Yaspin.attrs
#
def test_attrs_getter(supported_attrs):
    attrs = supported_attrs
    sp = yaspin(attrs=attrs)
    assert set(sp.attrs) == set(attrs)


def test_attrs_setter(attrs_test_cases):
    attrs, expected = attrs_test_cases
    sp = yaspin()

    if isinstance(expected, Exception):
        with pytest.raises(type(expected)):
            sp.attrs = attrs
    else:
        sp.attrs = attrs
        assert sp._attrs == set(expected)



"""
examples.advanced_colors
~~~~~~~~~~~~~~~~~~~~~~~~

Use familiar API of the `termcolor.colored` function to apply any
color, highlight, attribute or their mix to your yaspin spinner.
"""

import time

from yaspin import yaspin


def white_shark():
    # Set with attributes
    with yaspin().white.bold.shark.on_blue as sp:
        sp.text = "White bold shark in a blue sea 🦈"
        time.sleep(5)


def ping_pong():
    # Set with attributes
    with yaspin(text="🏓").yellow.bold.underline.pong.on_blue:
        time.sleep(5)


def ball():
    # Set with arguments
    with yaspin(
        color="white",
        on_color="on_magenta",
        attrs=["dark", "blink", "concealed"],
    ).bouncingBall as sp:
        sp.text = "Dark blink concealed white ball on magenta color"
        time.sleep(5)


def main():
    white_shark()
    ping_pong()
    ball()


if __name__ == "__main__":
    main()



"""
examples.signals
~~~~~~~~~~~~~~~~

Handling signals.

Reference
---------

- Signals in a nutshell:
    https://twitter.com/b0rk/status/981678748763414529

- More detailed overview:
    https://jvns.ca/blog/2016/06/13/should-you-be-scared-of-signals/

- Python signal module examples:
    https://pymotw.com/3/signal/index.html

- Linux signals reference:
    https://www.computerhope.com/unix/signals.htm#linux

"""

import os
import random
import signal
import sys
import time

from yaspin import kbi_safe_yaspin, yaspin
from yaspin.signal_handlers import fancy_handler
from yaspin.spinners import Spinners


DEFAULT_TEXT = "Press Control+C to send SIGINT (Keyboard Interrupt) signal"


#
# Basic usage
#
def simple_keyboard_interrupt_handling():
    with kbi_safe_yaspin(text=DEFAULT_TEXT):
        time.sleep(5)


# Set the handler for signal signalnum to the function handler.
# Handler can be a callable Python object taking two arguments,
# or one of the special values signal.SIG_IGN or signal.SIG_DFL.
def fancy_keyboard_interrupt_handler():
    with yaspin(sigmap={signal.SIGINT: fancy_handler}, text=DEFAULT_TEXT):
        time.sleep(5)


#
# Customizing signal handlers
#
def custom_signal_handler():
    def my_handler(signum, frame, spinner):
        spinner.red.fail("[Received SIGINT]")
        spinner.stop()
        sys.exit(0)

    with yaspin(sigmap={signal.SIGINT: my_handler}, text=DEFAULT_TEXT):
        time.sleep(5)


def passing_additional_info_into_signal_handler():
    heads = random.randint(0, 1) == 1
    tails = not heads

    def my_handler(signum, frame, spinner, context={"heads": heads, "tails": tails}):
        if context["heads"]:
            spinner.text = "heads!"
            spinner.ok("🌕")
        if context["tails"]:
            spinner.text = "tails!"
            spinner.ok("⚪")

        spinner.stop()
        sys.exit(0)

    with yaspin(sigmap={signal.SIGINT: my_handler}).toggle8 as sp:
        sp.text = "Tossing a coin... Press Control-C to view the result"
        time.sleep(10)
        sp.write("The coin has disappeared")


def handling_multiple_signals():
    def my_handler(signum, frame, spinner):
        if signum == int(signal.SIGUSR1):
            spinner.green.ok("[SIGUSR1]")
        if signum == int(signal.SIGTERM):
            spinner.red.ok("[SIGTERM]")

        spinner.stop()
        sys.exit(0)

    sigmap = {signal.SIGUSR1: my_handler, signal.SIGTERM: my_handler}

    with yaspin(sigmap=sigmap, text="Handling SIGUSR1 and SIGTERM") as sp:
        sp.write("Send signals using `kill` command")
        sp.write("E.g. $ kill -USR1 {0}".format(os.getpid()))
        time.sleep(60)
        sp.write("No signal received")


def ignore_signal():
    with yaspin(sigmap={signal.SIGINT: signal.SIG_IGN}, text="You can't interrupt me!"):
        time.sleep(5)


def default_os_handler_for_sigint():
    # Python sets ``signal.default_int_handler`` as a default handler
    # for SIGINT. It raises KeyboardInterrupt exception. It is also
    # possible to set default OS behavior for SIGINT by setting
    # ``signal.SIG_DFL`` as a signal handler.
    #
    # Generally ``signal.SIG_DFL`` performs the default function for the
    # signal.
    with yaspin(
        sigmap={signal.SIGINT: signal.SIG_DFL},
        text="Default OS handler for SIGINT",
    ):
        time.sleep(5)


#
# Real-world examples
#
def unpacker():
    swirl = yaspin(
        spinner=Spinners.simpleDotsScrolling,
        sigmap={signal.SIGINT: fancy_handler},
        side="right",
    )
    with swirl as sp:
        for p in range(0, 101, 5):
            sp.text = "{0}% Unpacking".format(p)
            time.sleep(random.random())
        sp.green.ok("✔")


def main():
    simple_keyboard_interrupt_handling()
    fancy_keyboard_interrupt_handler()
    custom_signal_handler()
    passing_additional_info_into_signal_handler()
    handling_multiple_signals()
    ignore_signal()
    default_os_handler_for_sigint()
    unpacker()


if __name__ == "__main__":
    main()



"""
examples.spinner_properties
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Updating spinner on the fly.
"""

import time

from yaspin import yaspin
from yaspin.spinners import Spinners


def manual_setup():
    sp = yaspin(text="Default spinner")
    sp.start()

    time.sleep(2)

    sp.spinner = Spinners.arc
    sp.text = "Right arc yellow spinner"
    sp.color = "yellow"
    sp.side = "right"

    time.sleep(3)

    sp.text = "Reversed arc spinner"
    sp.reversal = True

    time.sleep(3)

    sp.stop()


def context_mngr_setup():
    with yaspin(Spinners.noise, text="Noise spinner") as sp:
        time.sleep(2)

        sp.spinner = Spinners.simpleDotsScrolling
        sp.text = "Scrolling Dots spinner"
        sp.color = "magenta"

        time.sleep(2)


def main():
    manual_setup()
    context_mngr_setup()


if __name__ == "__main__":
    main()



"""
tests.test_pipes
~~~~~~~~~~~~~~~~

Checks that scripts with yaspin are safe
for pipes and redirects:

  $ python script_that_uses_yaspin.py > script.log
  $ python script_that_uses_yaspin.py | grep ERROR

"""

import os
import sys
import uuid

import pytest

from yaspin.constants import ENCODING


TEST_CODE = """\
import time
from yaspin import yaspin, Spinner

with yaspin(Spinner(%s, %s), '%s') as sp:
    time.sleep(0.5)
    sp.fail('🙀')
"""


def to_bytes(str_or_bytes, encoding=ENCODING):
    if isinstance(str_or_bytes, str):
        return str_or_bytes.encode(encoding)
    return str_or_bytes


def to_unicode(str_or_bytes, encoding=ENCODING):
    if isinstance(str_or_bytes, bytes):
        return str_or_bytes.decode(encoding)
    return str_or_bytes


@pytest.fixture()
def case_id():
    return str(uuid.uuid4())


def test_piping_output(
    text, frames, interval, case_id
):  # pylint: disable=redefined-outer-name
    py_fname = f"spin-{case_id}.py"
    fname = f"out-{case_id}.txt"

    def teardown():
        os.remove(py_fname)
        os.remove(fname)

    with open(py_fname, "wb") as f:
        text = to_unicode(text)
        interval = to_unicode(interval)
        code = to_unicode(TEST_CODE)
        res = code % (frames, interval, text)
        f.write(to_bytes(res))

    try:
        # $ python spin.py > out.txt
        os.system(f"{sys.executable} {py_fname} > {fname}")
    except UnicodeEncodeError as err:
        pytest.fail(err)
    finally:
        teardown()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['yaspin']

package_data = \
{'': ['*'], 'yaspin': ['data/*']}

install_requires = \
['termcolor>=2.2,<3.0']

setup_kwargs = {
    'name': 'yaspin',
    'version': '2.3.0',
    'description': 'Yet Another Terminal Spinner',
    'long_description': '|Logo|\n\n=====================================================================\n``yaspin``: **Y**\\ et **A**\\ nother Terminal **Spin**\\ ner for Python\n=====================================================================\n\n|Coverage| |pypi| |black-fmt|\n\n|Versions| |Wheel| |Examples|\n\n|DownloadsTot| |DownloadsW|\n\n\n``Yaspin`` provides a full-featured terminal spinner to show the progress during long-hanging operations.\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/demo.gif\n\nIt is easy to integrate into existing codebase by using it as a `context manager`_\nor as a function `decorator`_:\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    # Context manager:\n    with yaspin():\n        time.sleep(3)  # time consuming code\n\n    # Function decorator:\n    @yaspin(text="Loading...")\n    def some_operations():\n        time.sleep(3)  # time consuming code\n\n    some_operations()\n\n\n**Yaspin** also provides an intuitive and powerful API. For example, you can easily summon a shark:\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    with yaspin().white.bold.shark.on_blue as sp:\n        sp.text = "White bold shark in a blue sea"\n        time.sleep(5)\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/shark.gif\n\n\nFeatures\n--------\n\n- Runs at all major **CPython** versions (*3.7*, *3.8*, *3.9*, *3.10*, *3.11*), **PyPy**\n- Supports all (70+) spinners from `cli-spinners`_\n- Supports all *colors*, *highlights*, *attributes* and their mixes from `termcolor`_ library\n- Easy to combine with other command-line libraries, e.g. `prompt-toolkit`_\n- Flexible API, easy to integrate with existing code\n- User-friendly API for handling POSIX `signals`_\n- Safe **pipes** and **redirects**:\n\n.. code-block:: bash\n\n    $ python script_that_uses_yaspin.py > script.log\n    $ python script_that_uses_yaspin.py | grep ERROR\n\n\nInstallation\n------------\n\nFrom `PyPI`_ using ``pip`` package manager:\n\n.. code-block:: bash\n\n    pip install --upgrade yaspin\n\n\nOr install the latest sources from GitHub:\n\n.. code-block:: bash\n\n    pip install https://github.com/pavdmyt/yaspin/archive/master.zip\n\n\nUsage\n-----\n\nBasic Example\n/////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/basic_example.gif\n\n.. code:: python\n\n    import time\n    from random import randint\n    from yaspin import yaspin\n\n    with yaspin(text="Loading", color="yellow") as spinner:\n        time.sleep(2)  # time consuming code\n\n        success = randint(0, 1)\n        if success:\n            spinner.ok("✅ ")\n        else:\n            spinner.fail("💥 ")\n\n\nIt is also possible to control spinner manually:\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    spinner = yaspin()\n    spinner.start()\n\n    time.sleep(3)  # time consuming tasks\n\n    spinner.stop()\n\n\nRun any spinner from `cli-spinners`_\n////////////////////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/cli_spinners.gif\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n    from yaspin.spinners import Spinners\n\n    with yaspin(Spinners.earth, text="Earth") as sp:\n        time.sleep(2)                # time consuming code\n\n        # change spinner\n        sp.spinner = Spinners.moon\n        sp.text = "Moon"\n\n        time.sleep(2)                # time consuming code\n\n\nAny Colour You Like `🌈`_\n/////////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/basic_colors.gif\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    with yaspin(text="Colors!") as sp:\n        # Support all basic termcolor text colors\n        colors = ("red", "green", "yellow", "blue", "magenta", "cyan", "white")\n\n        for color in colors:\n            sp.color, sp.text = color, color\n            time.sleep(1)\n\n\nAdvanced colors usage\n/////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/advanced_colors.gif\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n    from yaspin.spinners import Spinners\n\n    text = "Bold blink magenta spinner on cyan color"\n    with yaspin().bold.blink.magenta.bouncingBall.on_cyan as sp:\n        sp.text = text\n        time.sleep(3)\n\n    # The same result can be achieved by passing arguments directly\n    with yaspin(\n        Spinners.bouncingBall,\n        color="magenta",\n        on_color="on_cyan",\n        attrs=["bold", "blink"],\n    ) as sp:\n        sp.text = text\n        time.sleep(3)\n\n\nRun any spinner you want\n////////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/custom_spinners.gif\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin, Spinner\n\n    # Compose new spinners with custom frame sequence and interval value\n    sp = Spinner(["😸", "😹", "😺", "😻", "😼", "😽", "😾", "😿", "🙀"], 200)\n\n    with yaspin(sp, text="Cat!"):\n        time.sleep(3)  # cat consuming code :)\n\n\nChange spinner properties on the fly\n////////////////////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/sp_properties.gif\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n    from yaspin.spinners import Spinners\n\n    with yaspin(Spinners.noise, text="Noise spinner") as sp:\n        time.sleep(2)\n\n        sp.spinner = Spinners.arc  # spinner type\n        sp.text = "Arc spinner"    # text along with spinner\n        sp.color = "green"         # spinner color\n        sp.side = "right"          # put spinner to the right\n        sp.reversal = True         # reverse spin direction\n\n        time.sleep(2)\n\n\nSpinner with timer\n//////////////////\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    with yaspin(text="elapsed time", timer=True) as sp:\n        time.sleep(3.1415)\n        sp.ok()\n\n\nDynamic text\n////////////\n\n.. code:: python\n\n    import time\n    from datetime import datetime\n    from yaspin import yaspin\n\n    class TimedText:\n        def __init__(self, text):\n            self.text = text\n            self._start = datetime.now()\n\n        def __str__(self):\n            now = datetime.now()\n            delta = now - self._start\n            return f"{self.text} ({round(delta.total_seconds(), 1)}s)"\n\n    with yaspin(text=TimedText("time passed:")):\n        time.sleep(3)\n\n\nWriting messages\n////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/write_text.gif\n\nYou should not write any message in the terminal using ``print`` while spinner is open.\nTo write messages in the terminal without any collision with ``yaspin`` spinner, a ``.write()`` method is provided:\n\n.. code:: python\n\n    import time\n    from yaspin import yaspin\n\n    with yaspin(text="Downloading images", color="cyan") as sp:\n        # task 1\n        time.sleep(1)\n        sp.write("> image 1 download complete")\n\n        # task 2\n        time.sleep(2)\n        sp.write("> image 2 download complete")\n\n        # finalize\n        sp.ok("✔")\n\n\nIntegration with other libraries\n////////////////////////////////\n\n.. image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/gifs/hide_show.gif\n\nUtilizing ``hidden`` context manager it is possible to toggle the display of\nthe spinner in order to call custom methods that write to the terminal. This is\nhelpful for allowing easy usage in other frameworks like `prompt-toolkit`_.\nUsing the powerful ``print_formatted_text`` function allows you even to apply\nHTML formats and CSS styles to the output:\n\n.. code:: python\n\n    import sys\n    import time\n\n    from yaspin import yaspin\n    from prompt_toolkit import HTML, print_formatted_text\n    from prompt_toolkit.styles import Style\n\n    # override print with feature-rich ``print_formatted_text`` from prompt_toolkit\n    print = print_formatted_text\n\n    # build a basic prompt_toolkit style for styling the HTML wrapped text\n    style = Style.from_dict({\n        \'msg\': \'#4caf50 bold\',\n        \'sub-msg\': \'#616161 italic\'\n    })\n\n\n    with yaspin(text=\'Downloading images\') as sp:\n        # task 1\n        time.sleep(1)\n        with sp.hidden():\n            print(HTML(\n                u\'<b>></b> <msg>image 1</msg> <sub-msg>download complete</sub-msg>\'\n            ), style=style)\n\n        # task 2\n        time.sleep(2)\n        with sp.hidden():\n            print(HTML(\n                u\'<b>></b> <msg>image 2</msg> <sub-msg>download complete</sub-msg>\'\n            ), style=style)\n\n        # finalize\n        sp.ok()\n\n\nHandling POSIX `signals`_\n/////////////////////////\n\nHandling keyboard interrupts (pressing Control-C):\n\n.. code:: python\n\n    import time\n\n    from yaspin import kbi_safe_yaspin\n\n\n    with kbi_safe_yaspin(text="Press Control+C to send SIGINT (Keyboard Interrupt) signal"):\n        time.sleep(5)  # time consuming code\n\n\nHandling other types of signals:\n\n.. code:: python\n\n    import os\n    import time\n    from signal import SIGTERM, SIGUSR1\n\n    from yaspin import yaspin\n    from yaspin.signal_handlers import default_handler, fancy_handler\n\n\n    sigmap = {SIGUSR1: default_handler, SIGTERM: fancy_handler}\n    with yaspin(sigmap=sigmap, text="Handling SIGUSR1 and SIGTERM signals") as sp:\n        sp.write("Send signals using `kill` command")\n        sp.write("E.g. $ kill -USR1 {0}".format(os.getpid()))\n        time.sleep(20)  # time consuming code\n\n\nMore `examples`_.\n\n\nDevelopment\n-----------\n\nClone the repository:\n\n.. code-block:: bash\n\n    git clone https://github.com/pavdmyt/yaspin.git\n\n\nInstall dev dependencies:\n\n.. code-block:: bash\n\n    poetry install\n\n    # if you don\'t have poetry installed:\n    pip install -r requirements.txt\n\n\nLint code:\n\n.. code-block:: bash\n\n    make lint\n\n\nFormat code:\n\n.. code-block:: bash\n\n    make black-fmt\n\n\nRun tests:\n\n.. code-block:: bash\n\n    make test\n\n\nContributing\n------------\n\n1. Fork it!\n2. Create your feature branch: ``git checkout -b my-new-feature``\n3. Commit your changes: ``git commit -m \'Add some feature\'``\n4. Push to the branch: ``git push origin my-new-feature``\n5. Submit a pull request\n6. Make sure tests are passing\n\n\nLicense\n-------\n\n* MIT - Pavlo Dmytrenko; https://twitter.com/pavdmyt\n* Contains data from `cli-spinners`_: MIT License, Copyright (c) Sindre Sorhus sindresorhus@gmail.com (sindresorhus.com)\n\n\n.. |Logo| image:: https://raw.githubusercontent.com/pavdmyt/yaspin/master/static/logo_80.png\n   :alt: yaspin Logo\n.. |Coverage| image:: https://codecov.io/gh/pavdmyt/yaspin/branch/master/graph/badge.svg\n   :target: https://codecov.io/gh/pavdmyt/yaspin\n.. |pypi| image:: https://img.shields.io/pypi/v/yaspin.svg\n   :target: https://pypi.org/project/yaspin/\n.. |Versions| image:: https://img.shields.io/pypi/pyversions/yaspin.svg\n   :target: https://pypi.org/project/yaspin/\n.. |Wheel| image:: https://img.shields.io/pypi/wheel/yaspin.svg\n   :target: https://pypi.org/project/yaspin/\n.. |Examples| image:: https://img.shields.io/badge/learn%20by-examples-0077b3.svg\n   :target: https://github.com/pavdmyt/yaspin/tree/master/examples\n.. |black-fmt| image:: https://img.shields.io/badge/code%20style-black-000000.svg\n   :target: https://github.com/ambv/black\n.. |DownloadsTot| image:: https://pepy.tech/badge/yaspin\n   :target: https://pepy.tech/project/yaspin\n.. |DownloadsW| image:: https://pepy.tech/badge/yaspin/week\n   :target: https://pepy.tech/project/yaspin\n\n\n.. _context manager: https://docs.python.org/3/reference/datamodel.html#context-managers\n.. _decorator: https://www.thecodeship.com/patterns/guide-to-python-function-decorators/\n.. _cli-spinners: https://github.com/sindresorhus/cli-spinners\n.. _termcolor: https://pypi.org/project/termcolor/\n.. _PyPI: https://pypi.org/\n.. _🌈: https://en.wikipedia.org/wiki/Any_Colour_You_Like\n.. _examples: https://github.com/pavdmyt/yaspin/tree/master/examples\n.. _prompt-toolkit: https://github.com/jonathanslenders/python-prompt-toolkit/\n.. _signals: https://www.computerhope.com/unix/signals.htm\n',
    'author': 'Pavlo Dmytrenko',
    'author_email': 'mail@pavdmyt.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/pavdmyt/yaspin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
